@@ -1,6 +1,6 @@
 /* engine-gpgsm.c - GpgSM engine.
    Copyright (C) 2000 Werner Koch (dd9jn)
-   Copyright (C) 2001, 2002, 2003, 2004 g10 Code GmbH
+   Copyright (C) 2001, 2002, 2003 g10 Code GmbH
  
    This file is part of GPGME.
 
@@ -152,9 +152,6 @@ close_notify_handler (int fd, void *opaque)
 static gpgme_error_t
 map_assuan_error (AssuanError err)
 {
-  if (err == -1)
-    return gpg_error (GPG_ERR_INV_ENGINE);
-
   /* New code will use gpg_error_t values.  */
   if (gpg_err_source (err))
     return (gpgme_error_t) err;
@@ -272,13 +269,13 @@ map_assuan_error (AssuanError err)
 }
 
 
-static gpgme_error_t
-gpgsm_cancel (void *engine)
+static void
+gpgsm_release (void *engine)
 {
   engine_gpgsm_t gpgsm = engine;
 
   if (!gpgsm)
-    return gpg_error (GPG_ERR_INV_VALUE);
+    return;
 
   if (gpgsm->status_cb.fd != -1)
     _gpgme_io_close (gpgsm->status_cb.fd);
@@ -291,27 +288,13 @@ gpgsm_cancel (void *engine)
 
   assuan_disconnect (gpgsm->assuan_ctx);
 
-  return 0;
-}
-
-
-static void
-gpgsm_release (void *engine)
-{
-  engine_gpgsm_t gpgsm = engine;
-
-  if (!gpgsm)
-    return;
-
-  gpgsm_cancel (engine);
-
   free (gpgsm->colon.attic.line);
   free (gpgsm);
 }
 
 
 static gpgme_error_t
-gpgsm_new (void **engine, const char *lc_ctype, const char *lc_messages)
+gpgsm_new (void **engine)
 {
   gpgme_error_t err = 0;
   engine_gpgsm_t gpgsm;
@@ -319,8 +302,10 @@ gpgsm_new (void **engine, const char *lc_ctype, const char *lc_messages)
   int fds[2];
   int child_fds[4];
   char *dft_display = NULL;
-  char dft_ttyname[64];
+  char *dft_ttyname = NULL;
   char *dft_ttytype = NULL;
+  char *old_lc = NULL;
+  char *dft_lc = NULL;
   char *optstr;
   int fdlist[5];
   int nfds;
@@ -418,19 +403,14 @@ gpgsm_new (void **engine, const char *lc_ctype, const char *lc_messages)
   gpgsm->status_cb.dir = 1;
   gpgsm->status_cb.data = gpgsm;
 
-  err = _gpgme_getenv ("DISPLAY", &dft_display);
-  if (err)
-    goto leave;
+  dft_display = getenv ("DISPLAY");
   if (dft_display)
     {
       if (asprintf (&optstr, "OPTION display=%s", dft_display) < 0)
         {
-	  free (dft_display);
 	  err = gpg_error_from_errno (errno);
 	  goto leave;
 	}
-      free (dft_display);
-
       err = assuan_transact (gpgsm->assuan_ctx, optstr, NULL, NULL, NULL,
 			     NULL, NULL, NULL);
       free (optstr);
@@ -440,13 +420,8 @@ gpgsm_new (void **engine, const char *lc_ctype, const char *lc_messages)
 	  goto leave;
 	}
     }
-
-  if (ttyname_r (1, dft_ttyname, sizeof (dft_ttyname)))
-    {
-      err = gpg_error_from_errno (errno);
-      goto leave;
-    }
-  else
+  dft_ttyname = ttyname (1);
+  if (dft_ttyname)
     {
       if (asprintf (&optstr, "OPTION ttyname=%s", dft_ttyname) < 0)
         {
@@ -462,19 +437,14 @@ gpgsm_new (void **engine, const char *lc_ctype, const char *lc_messages)
 	  goto leave;
 	}
 
-      err = _gpgme_getenv ("TERM", &dft_ttytype);
-      if (err)
-	goto leave;
+      dft_ttytype = getenv ("TERM");
       if (dft_ttytype)
 	{
 	  if (asprintf (&optstr, "OPTION ttytype=%s", dft_ttytype) < 0)
 	    {
-	      free (dft_ttytype);
 	      err = gpg_error_from_errno (errno);
 	      goto leave;
 	    }
-	  free (dft_ttytype);
-
 	  err = assuan_transact (gpgsm->assuan_ctx, optstr, NULL, NULL, NULL,
 				 NULL, NULL, NULL);
 	  free (optstr);
@@ -485,25 +455,52 @@ gpgsm_new (void **engine, const char *lc_ctype, const char *lc_messages)
 	    }
 	}
 
-      if (lc_ctype)
+      old_lc = setlocale (LC_CTYPE, NULL);
+      if (old_lc)
+        {
+          old_lc = strdup (old_lc);
+          if (!old_lc)
+            {
+              err = gpg_error_from_errno (errno);
+              goto leave;
+            }
+        }
+      dft_lc = setlocale (LC_CTYPE, "");
+      if (dft_lc)
 	{
-	  if (asprintf (&optstr, "OPTION lc-ctype=%s", lc_ctype) < 0)
+	  if (asprintf (&optstr, "OPTION lc-ctype=%s", dft_lc) < 0)
 	    err = gpg_error_from_errno (errno);
 	  else
 	    {
 	      err = assuan_transact (gpgsm->assuan_ctx, optstr, NULL, NULL,
-				     NULL, NULL, NULL, NULL);
+                                     NULL, NULL, NULL, NULL);
 	      free (optstr);
 	      if (err)
 		err = map_assuan_error (err);
 	    }
 	}
+      if (old_lc)
+        {
+          setlocale (LC_CTYPE, old_lc);
+          free (old_lc);
+        }
       if (err)
 	goto leave;
 
-      if (lc_messages)
+      old_lc = setlocale (LC_MESSAGES, NULL);
+      if (old_lc)
+        {
+          old_lc = strdup (old_lc);
+          if (!old_lc)
+            {
+              err = gpg_error_from_errno (errno);
+              goto leave;
+            }
+        }
+      dft_lc = setlocale (LC_MESSAGES, "");
+      if (dft_lc)
 	{
-	  if (asprintf (&optstr, "OPTION lc-messages=%s", lc_messages) < 0)
+	  if (asprintf (&optstr, "OPTION lc-messages=%s", dft_lc) < 0)
 	    err = gpg_error_from_errno (errno);
 	  else
 	    {
@@ -514,19 +511,24 @@ gpgsm_new (void **engine, const char *lc_ctype, const char *lc_messages)
 		err = map_assuan_error (err);
 	    }
 	}
+      if (old_lc)
+        {
+          setlocale (LC_MESSAGES, old_lc);
+          free (old_lc);
+        }
       if (err)
 	goto leave;
     }
 
-  if (!err
-      && (_gpgme_io_set_close_notify (gpgsm->status_cb.fd,
+  if (!err &&
+      (_gpgme_io_set_close_notify (gpgsm->status_cb.fd,
+				   close_notify_handler, gpgsm)
+       || _gpgme_io_set_close_notify (gpgsm->input_cb.fd,
+				   close_notify_handler, gpgsm)
+       || _gpgme_io_set_close_notify (gpgsm->output_cb.fd,
 				      close_notify_handler, gpgsm)
-	  || _gpgme_io_set_close_notify (gpgsm->input_cb.fd,
-					 close_notify_handler, gpgsm)
-	  || _gpgme_io_set_close_notify (gpgsm->output_cb.fd,
-					 close_notify_handler, gpgsm)
-	  || _gpgme_io_set_close_notify (gpgsm->message_cb.fd,
-					 close_notify_handler, gpgsm)))
+       || _gpgme_io_set_close_notify (gpgsm->message_cb.fd,
+				      close_notify_handler, gpgsm)))
     {
       err = gpg_error (GPG_ERR_GENERAL);
       goto leave;
@@ -599,7 +601,7 @@ gpgsm_assuan_simple_command (ASSUAN_CONTEXT ctx, char *cmd,
 	  r = parse_status (line + 2);
 
 	  if (r >= 0 && status_fnc)
-	    err = status_fnc (status_fnc_value, r, rest);
+	    status_fnc (status_fnc_value, r, rest);
 	  else
 	    err = gpg_error (GPG_ERR_GENERAL);
 	}
@@ -683,7 +685,7 @@ status_handler (void *opaque, int fd)
       if (assuan_err)
 	{
 	  /* Try our best to terminate the connection friendly.  */
-	  /*	  assuan_write_line (gpgsm->assuan_ctx, "BYE"); */
+	  assuan_write_line (gpgsm->assuan_ctx, "BYE");
 	  err = map_assuan_error (assuan_err);
 	}
       else if (linelen >= 3
@@ -1106,6 +1108,7 @@ gpgsm_export_ext (void *engine, const char *pattern[], unsigned int reserved,
 	      patlet++;
 	    }
 	  pat++;
+	  /* This will allocate one byte more than necessary.  */
 	  length++;
 	}
     }
@@ -1148,8 +1151,6 @@ gpgsm_export_ext (void *engine, const char *pattern[], unsigned int reserved,
 	      patlet++;
 	    }
 	  pattern++;
-          if (*pattern)
-            *linep++ = ' ';
 	}
     }
   *linep = '\0';
@@ -1241,16 +1242,6 @@ gpgsm_keylist (void *engine, const char *pattern, int secret_only,
   if (err)
     return err;
 
-
-  /* Use the validation mode if required.  We don't check for an error
-     yet because this is a pretty fresh gpgsm features. */
-  gpgsm_assuan_simple_command (gpgsm->assuan_ctx, 
-                               (mode & GPGME_KEYLIST_MODE_VALIDATE)?
-                               "OPTION with-validation=1":
-                               "OPTION with-validation=0" ,
-                               NULL, NULL);
-
-
   /* Length is "LISTSECRETKEYS " + p + '\0'.  */
   line = malloc (15 + strlen (pattern) + 1);
   if (!line)
@@ -1555,6 +1546,5 @@ struct engine_ops _gpgme_engine_ops_gpgsm =
     NULL,		/* trustlist */
     gpgsm_verify,
     gpgsm_set_io_cbs,
-    gpgsm_io_event,
-    gpgsm_cancel
+    gpgsm_io_event
   };
