@@ -116,6 +116,15 @@ keylist_status_handler (void *priv, gpgme_status_code_t code, char *args)
 }
 
 
+static time_t
+parse_timestamp (char *timestamp)
+{
+  if (!*timestamp)
+    return 0;
+
+  return (time_t) strtoul (timestamp, NULL, 10);
+}
+
 
 static void
 set_mainkey_trust_info (gpgme_key_t key, const char *src)
@@ -236,10 +245,6 @@ set_mainkey_capability (gpgme_key_t key, const char *src)
 	  key->subkeys->can_certify = 1;
 	  break;
 
-	case 'a':
-	  key->subkeys->can_authenticate = 1;
-	  break;
-
         case 'd':
         case 'D':
           /* Note, that this flag is also set using the key validity
@@ -261,10 +266,6 @@ set_mainkey_capability (gpgme_key_t key, const char *src)
 	case 'C':
 	  key->can_certify = 1;
 	  break;
-
-	case 'A':
-	  key->can_authenticate = 1;
-	  break;
         }
       src++;
     }
@@ -289,10 +290,6 @@ set_subkey_capability (gpgme_subkey_t subkey, const char *src)
 	case 'c':
 	  subkey->can_certify = 1;
 	  break;
-
-	case 'a':
-	  subkey->can_authenticate = 1;
-	  break;
         }
       src++;
     }
@@ -472,11 +469,11 @@ keylist_colon_handler (void *priv, char *line)
 
       /* Field 6 has the timestamp (seconds).  */
       if (fields >= 6)
-	subkey->timestamp = _gpgme_parse_timestamp (field[5], NULL);
+	subkey->timestamp = parse_timestamp (field[5]);
 
       /* Field 7 has the expiration time (seconds).  */
       if (fields >= 7)
-	subkey->expires = _gpgme_parse_timestamp (field[6], NULL);
+	subkey->expires = parse_timestamp (field[6]);
 
       /* Field 8 has the X.509 serial number.  */
       if (fields >= 8 && (rectype == RT_CRT || rectype == RT_CRS))
@@ -540,11 +537,11 @@ keylist_colon_handler (void *priv, char *line)
 
       /* Field 6 has the timestamp (seconds).  */
       if (fields >= 6)
-	subkey->timestamp = _gpgme_parse_timestamp (field[5], NULL);
+	subkey->timestamp = parse_timestamp (field[5]);
 
       /* Field 7 has the expiration time (seconds).  */
       if (fields >= 7)
-	subkey->expires = _gpgme_parse_timestamp (field[6], NULL);
+	subkey->expires = parse_timestamp (field[6]);
 
       /* Field 8 is reserved (LID).  */
       /* Field 9 has the ownertrust.  */
@@ -640,22 +637,21 @@ keylist_colon_handler (void *priv, char *line)
       
       /* Field 6 has the timestamp (seconds).  */
       if (fields >= 6)
-	keysig->timestamp = _gpgme_parse_timestamp (field[5], NULL);
+	keysig->timestamp = parse_timestamp (field[5]);
 
       /* Field 7 has the expiration time (seconds).  */
       if (fields >= 7)
-	keysig->expires = _gpgme_parse_timestamp (field[6], NULL);
+	keysig->expires = parse_timestamp (field[6]);
 
       /* Field 11 has the signature class (eg, 0x30 means revoked).  */
       if (fields >= 11)
 	if (field[10][0] && field[10][1])
 	  {
-	    int sig_class = _gpgme_hextobyte (field[10]);
-	    if (sig_class >= 0)
+	    int class = _gpgme_hextobyte (field[10]);
+	    if (class >= 0)
 	      {
-		keysig->sig_class = sig_class;
-		keysig->class = keysig->sig_class;
-		if (sig_class == 0x30)
+		keysig->class = class;
+		if (class == 0x30)
 		  keysig->revoked = 1;
 	      }
 	    if (field[10][2] == 'x')
@@ -836,7 +832,6 @@ gpgme_get_key (gpgme_ctx_t ctx, const char *fpr, gpgme_key_t *r_key,
 {
   gpgme_ctx_t listctx;
   gpgme_error_t err;
-  gpgme_key_t key;
 
   if (!ctx || !r_key)
     return gpg_error (GPG_ERR_INV_VALUE);
@@ -854,21 +849,6 @@ gpgme_get_key (gpgme_ctx_t ctx, const char *fpr, gpgme_key_t *r_key,
   err = gpgme_op_keylist_start (listctx, fpr, secret);
   if (!err)
     err = gpgme_op_keylist_next (listctx, r_key);
-  if (!err)
-    {
-      err = gpgme_op_keylist_next (listctx, &key);
-      if (gpgme_err_code (err) == GPG_ERR_EOF)
-	err = gpg_error (GPG_ERR_NO_ERROR);
-      else
-	{
-	  if (!err)
-	    {
-	      gpgme_key_unref (key);
-	      err = gpg_error (GPG_ERR_AMBIGUOUS_NAME);
-	    }
-	  gpgme_key_unref (*r_key);
-	}
-    }
   gpgme_release (listctx);
   return err;
 }
