@@ -26,6 +26,12 @@
 #include <string.h>
 #include <assert.h>
 #include <errno.h>
+#include <time.h>
+#include <sys/time.h>
+#include <sys/types.h>
+#include <signal.h>
+#include <fcntl.h>
+#include "unistd.h"
 
 #include "gpgme.h"
 #include "util.h"
@@ -276,30 +282,6 @@ free_fd_data_map (struct fd_data_map_s *fd_data_map)
 }
 
 
-static gpgme_error_t
-gpg_cancel (void *engine)
-{
-  engine_gpg_t gpg = engine;
-
-  if (!gpg)
-    return gpg_error (GPG_ERR_INV_VALUE);
-
-  if (gpg->status.fd[0] != -1)
-    _gpgme_io_close (gpg->status.fd[0]);
-  if (gpg->status.fd[1] != -1)
-    _gpgme_io_close (gpg->status.fd[1]);
-  if (gpg->colon.fd[0] != -1)
-    _gpgme_io_close (gpg->colon.fd[0]);
-  if (gpg->colon.fd[1] != -1)
-    _gpgme_io_close (gpg->colon.fd[1]);
-  if (gpg->fd_data_map)
-    free_fd_data_map (gpg->fd_data_map);
-  if (gpg->cmd.fd != -1)
-    _gpgme_io_close (gpg->cmd.fd);
-
-  return 0;
-}
-
 static void
 gpg_release (void *engine)
 {
@@ -308,8 +290,6 @@ gpg_release (void *engine)
   if (!gpg)
     return;
 
-  gpg_cancel (engine);
-
   while (gpg->arglist)
     {
       struct arg_and_data_s *next = gpg->arglist->next;
@@ -328,12 +308,24 @@ gpg_release (void *engine)
   if (gpg->cmd.keyword)
     free (gpg->cmd.keyword);
 
+  if (gpg->status.fd[0] != -1)
+    _gpgme_io_close (gpg->status.fd[0]);
+  if (gpg->status.fd[1] != -1)
+    _gpgme_io_close (gpg->status.fd[1]);
+  if (gpg->colon.fd[0] != -1)
+    _gpgme_io_close (gpg->colon.fd[0]);
+  if (gpg->colon.fd[1] != -1)
+    _gpgme_io_close (gpg->colon.fd[1]);
+  if (gpg->fd_data_map)
+    free_fd_data_map (gpg->fd_data_map);
+  if (gpg->cmd.fd != -1)
+    _gpgme_io_close (gpg->cmd.fd);
   free (gpg);
 }
 
 
 static gpgme_error_t
-gpg_new (void **engine, const char *lc_ctype, const char *lc_messages)
+gpg_new (void **engine)
 {
   engine_gpg_t gpg;
   gpgme_error_t rc = 0;
@@ -511,7 +503,6 @@ gpg_set_command_handler (void *engine, engine_command_handler_t fnc,
 static gpgme_error_t
 build_argv (engine_gpg_t gpg)
 {
-  gpgme_error_t err;
   struct arg_and_data_s *a;
   struct fd_data_map_s *fd_data_map;
   size_t datac=0, argc=0;  
@@ -523,13 +514,9 @@ build_argv (engine_gpg_t gpg)
   /* We don't want to use the agent with a malformed environment
      variable.  This is only a very basic test but sufficient to make
      our life in the regression tests easier. */
-  err = _gpgme_getenv ("GPG_AGENT_INFO", &p);
-  if (err)
-    return err;
+  p = getenv ("GPG_AGENT_INFO");
   use_agent = (p && strchr (p, ':'));
-  if (p)
-    free (p);
-
+       
   if (gpg->argv)
     {
       free_argv (gpg->argv);
@@ -563,7 +550,7 @@ build_argv (engine_gpg_t gpg)
     argc++;
   if (!gpg->cmd.used)
     argc++;	/* --batch */
-  argc += 1; /* --no-comment */
+  argc += 2; /* --comment */
 
   argv = calloc (argc + 1, sizeof *argv);
   if (!argv)
@@ -622,7 +609,16 @@ build_argv (engine_gpg_t gpg)
         }
       argc++;
     }
-  argv[argc] = strdup ("--no-comment");
+  argv[argc] = strdup ("--comment");
+  if (!argv[argc])
+    {
+      int saved_errno = errno;
+      free (fd_data_map);
+      free_argv (argv);
+      return gpg_error_from_errno (saved_errno);
+    }
+  argc++;
+  argv[argc] = strdup ("");
   if (!argv[argc])
     {
       int saved_errno = errno;
@@ -1101,7 +1097,7 @@ start (engine_gpg_t gpg)
   saved_errno = errno;
   free (fd_child_list);
   if (status == -1)
-    return gpg_error_from_errno (saved_errno);
+    return gpg_error_from_errno (errno);
 
   /*_gpgme_register_term_handler ( closure, closure_value, pid );*/
 
@@ -1223,7 +1219,7 @@ append_args_from_signers (engine_gpg_t gpg, gpgme_ctx_t ctx /* FIXME */)
 
 
 static gpgme_error_t
-gpg_edit (void *engine, int type, gpgme_key_t key, gpgme_data_t out,
+gpg_edit (void *engine, gpgme_key_t key, gpgme_data_t out,
 	  gpgme_ctx_t ctx /* FIXME */)
 {
   engine_gpg_t gpg = engine;
@@ -1233,7 +1229,7 @@ gpg_edit (void *engine, int type, gpgme_key_t key, gpgme_data_t out,
   if (!err)
     err = append_args_from_signers (gpg, ctx);
   if (!err)
-  err = add_arg (gpg, type == 0 ? "--edit-key" : "--card-edit");
+  err = add_arg (gpg, "--edit-key");
   if (!err)
     err = add_data (gpg, out, 1, 1);
   if (!err)
@@ -1678,6 +1674,5 @@ struct engine_ops _gpgme_engine_ops_gpg =
     gpg_trustlist,
     gpg_verify,
     gpg_set_io_cbs,
-    gpg_io_event,
-    gpg_cancel
+    gpg_io_event
   };
