@@ -198,7 +198,7 @@ parse_new_sig (op_data_t opd, gpgme_status_code_t code, char *args)
 		end++;
 	      i++;
 	    }
-	  if (end && end[0] && (!end[1] || end[1] == ' '))
+	  if (end && end[0] && (!end[1] || !end[1] == ' '))
 	    {
 	      switch (end[0])
 		{
@@ -206,7 +206,7 @@ parse_new_sig (op_data_t opd, gpgme_status_code_t code, char *args)
 		  sig->status = gpg_error (GPG_ERR_UNSUPPORTED_ALGORITHM);
 		  break;
 		  
-		case '9':
+		case 9:
 		  sig->status = gpg_error (GPG_ERR_NO_PUBKEY);
 		  break;
 		  
@@ -258,14 +258,14 @@ parse_valid_sig (gpgme_signature_t sig, char *args)
   if (end)
     {
       char *tail;
-
-      sig->timestamp = _gpgme_parse_timestamp (end, &tail);
-      if (sig->timestamp == -1 || end == tail || (*tail && *tail != ' '))
+      errno = 0;
+      sig->timestamp = strtol (end, &tail, 0);
+      if (errno || end == tail || (*tail && *tail != ' '))
 	return gpg_error (GPG_ERR_INV_ENGINE);
       end = tail;
      
-      sig->exp_timestamp = _gpgme_parse_timestamp (end, &tail);
-      if (sig->exp_timestamp == -1 || end == tail || (*tail && *tail != ' '))
+      sig->exp_timestamp = strtol (end, &tail, 0);
+      if (errno || end == tail || (*tail && *tail != ' '))
 	return gpg_error (GPG_ERR_INV_ENGINE);
     }
   return 0;
