@@ -1,23 +1,22 @@
-/* w32-io.c - W32 API I/O functions
- *	Copyright (C) 2000 Werner Koch (dd9jn)
- *      Copyright (C) 2001, 2002 g10 Code GmbH
- *
- * This file is part of GPGME.
- *
- * GPGME is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * GPGME is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
- */
+/* w32-io.c - W32 API I/O functions.
+   Copyright (C) 2000 Werner Koch (dd9jn)
+   Copyright (C) 2001, 2002, 2003 g10 Code GmbH
+
+   This file is part of GPGME.
+ 
+   GPGME is free software; you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
+ 
+   GPGME is distributed in the hope that it will be useful, but
+   WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+ 
+   You should have received a copy of the GNU General Public License
+   along with GPGME; if not, write to the Free Software Foundation,
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -39,12 +38,10 @@
 #include "io.h"
 
 
-/* 
- * We assume that a HANDLE can be represented by an int which should be true   
- * for all i386 systems (HANDLE is defined as void *) and these are the only
- * systems for which Windows is available.
- * Further we assume that -1 denotes an invalid handle.
- */
+/* We assume that a HANDLE can be represented by an int which should
+   be true for all i386 systems (HANDLE is defined as void *) and
+   these are the only systems for which Windows is available.  Further
+   we assume that -1 denotes an invalid handle.  */
 
 #define fd_to_handle(a)  ((HANDLE)(a))
 #define handle_to_fd(a)  ((int)(a))
@@ -226,7 +223,7 @@ create_reader (HANDLE fd)
     sec_attr.nLength = sizeof sec_attr;
     sec_attr.bInheritHandle = FALSE;
 
-    c = xtrycalloc (1, sizeof *c );
+    c = calloc (1, sizeof *c );
     if (!c)
         return NULL;
 
@@ -242,7 +239,7 @@ create_reader (HANDLE fd)
             CloseHandle (c->have_space_ev);
         if (c->stopped)
             CloseHandle (c->stopped);
-        xfree (c);
+        free (c);
         return NULL;
     }
 
@@ -260,7 +257,7 @@ create_reader (HANDLE fd)
             CloseHandle (c->have_space_ev);
         if (c->stopped)
             CloseHandle (c->stopped);
-        xfree (c);
+        free (c);
         return NULL;
     }    
 
@@ -288,7 +285,7 @@ destroy_reader (struct reader_context_s *c)
         CloseHandle (c->have_space_ev);
     CloseHandle (c->thread_hd);
     DESTROY_LOCK (c->mutex);
-    xfree (c);
+    free (c);
 }
 
 
@@ -479,7 +476,7 @@ create_writer (HANDLE fd)
     sec_attr.nLength = sizeof sec_attr;
     sec_attr.bInheritHandle = FALSE;
 
-    c = xtrycalloc (1, sizeof *c );
+    c = calloc (1, sizeof *c );
     if (!c)
         return NULL;
 
@@ -495,7 +492,7 @@ create_writer (HANDLE fd)
             CloseHandle (c->is_empty);
         if (c->stopped)
             CloseHandle (c->stopped);
-        xfree (c);
+        free (c);
         return NULL;
     }
 
@@ -513,7 +510,7 @@ create_writer (HANDLE fd)
             CloseHandle (c->is_empty);
         if (c->stopped)
             CloseHandle (c->stopped);
-        xfree (c);
+        free (c);
         return NULL;
     }    
 
@@ -541,7 +538,7 @@ destroy_writer (struct writer_context_s *c)
         CloseHandle (c->is_empty);
     CloseHandle (c->thread_hd);
     DESTROY_LOCK (c->mutex);
-    xfree (c);
+    free (c);
 }
 
 
@@ -771,7 +768,7 @@ build_commandline ( char **argv )
      * program parses the commandline and does some unquoting */
     for (i=0; argv[i]; i++)
         n += strlen (argv[i]) + 2 + 1; /* 2 extra bytes for possible quoting */
-    buf = p = xtrymalloc (n);
+    buf = p = malloc (n);
     if ( !buf )
         return NULL;
     *buf = 0;
@@ -859,7 +856,7 @@ _gpgme_io_spawn ( const char *path, char **argv,
                             NULL );
         if ( hnul == INVALID_HANDLE_VALUE ) {
             DEBUG1 ("can't open `nul': ec=%d\n", (int)GetLastError ());
-            xfree (arg_string);
+            free (arg_string);
             return -1;
         }
         /* Make sure that the process has a connected stdin */
@@ -888,7 +885,7 @@ _gpgme_io_spawn ( const char *path, char **argv,
                           &pi            /* returns process information */
         ) ) {
         DEBUG1 ("CreateProcess failed: ec=%d\n", (int) GetLastError ());
-        xfree (arg_string);
+        free (arg_string);
         return -1;
     }
 
@@ -992,7 +989,7 @@ _gpgme_io_select ( struct io_select_fd_s *fds, size_t nfds, int nonblock )
     void *dbg_help;
 
  restart:
-    DEBUG_BEGIN (dbg_help, "select on [ ");
+    DEBUG_BEGIN (dbg_help, 3, "select on [ ");
     any = 0;
     nwait = 0;
     count = 0;
@@ -1103,7 +1100,7 @@ _gpgme_io_select ( struct io_select_fd_s *fds, size_t nfds, int nonblock )
     }
 
     if ( count ) {
-        DEBUG_BEGIN (dbg_help, " signaled [ ");
+        DEBUG_BEGIN (dbg_help, 3, " signaled [ ");
         for ( i=0; i < nfds; i++ ) {
             if ( fds[i].fd == -1 ) 
                 continue;
