@@ -18,12 +18,6 @@
    along with GPGME; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-/* We need to include config.h so that we know whether we are building
-   with large file system (LFS) support. */
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -119,8 +113,6 @@ main (int argc, char **argv)
   const char *pattern = "Alpha";
   char *agent_info;
 
-  init_gpgme (GPGME_PROTOCOL_OpenPGP);
-
   err = gpgme_new (&ctx);
   fail_if_err (err);
   err = gpgme_data_new (&out);
@@ -149,3 +141,5 @@ main (int argc, char **argv)
 
   return 0;
 }
+
+
