@@ -18,12 +18,6 @@
    along with GPGME; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-/* We need to include config.h so that we know whether we are building
-   with large file system (LFS) support. */
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -74,8 +68,6 @@ main (int argc, char **argv)
     "</GnupgKeyParms>\n";
   gpgme_genkey_result_t result;
 
-  init_gpgme (GPGME_PROTOCOL_OpenPGP);
-
   err = gpgme_new (&ctx);
   fail_if_err (err);
 
