@@ -18,12 +18,6 @@
    along with GPGME; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-/* We need to include config.h so that we know whether we are building
-   with large file system (LFS) support. */
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -89,10 +83,7 @@ check_result (gpgme_import_result_t result, char *fpr, int secret)
     {
       fprintf (stderr, "Unexpected number of new signatures %i\n",
 	       result->new_signatures);
-      if (result->new_signatures == 2)
-        fprintf (stderr, "### ignored due to gpg 1.3.4 problems\n");
-      else
-        exit (1);
+      exit (1);
     }
   if (result->new_revocations != 0)
     {
@@ -212,8 +203,6 @@ main (int argc, char *argv[])
   const char *pubkey_1_asc = make_filename ("pubkey-1.asc");
   const char *seckey_1_asc = make_filename ("seckey-1.asc");
 
-  init_gpgme (GPGME_PROTOCOL_OpenPGP);
-
   err = gpgme_new (&ctx);
   fail_if_err (err);
 
