@@ -18,21 +18,26 @@
    along with GPGME; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-/* We need to include config.h so that we know whether we are building
-   with large file system (LFS) support. */
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 
 #include <gpgme.h>
 
-#include "t-support.h"
-
 
+#define fail_if_err(err)					\
+  do								\
+    {								\
+      if (err)							\
+        {							\
+          fprintf (stderr, "%s:%d: gpgme_error_t %s\n",		\
+                   __FILE__, __LINE__, gpgme_strerror (err));   \
+          exit (1);						\
+        }							\
+    }								\
+  while (0)
+
+
 struct
 {
   char *fpr;
@@ -48,13 +53,12 @@ keys[] =
   {
     { "3CF405464F66ED4A7DF45BBDD1E4282E33BDB76E", 1, 1007372198, 1038908198, "00",
       "CN=test cert 1,OU=Aegypten Project,O=g10 Code GmbH,L=D\xc3\xbcsseldorf,C=DE",
-      "3CF405464F66ED4A7DF45BBDD1E4282E33BDB76E",
+      NULL,
       "CN=test cert 1,OU=Aegypten Project,O=g10 Code GmbH,L=D\xc3\xbcsseldorf,C=DE" },
     { "DFA56FB5FC41E3A8921F77AD1622EEFD9152A5AD", 0, 909684190, 1009821790, "01",
       "1.2.840.113549.1.9.1=#63657274696679407063612E64666E2E6465,"
       "CN=DFN Top Level Certification Authority,OU=DFN-PCA,"
-      "O=Deutsches Forschungsnetz,C=DE",
-      "DFA56FB5FC41E3A8921F77AD1622EEFD9152A5AD",
+      "O=Deutsches Forschungsnetz,C=DE", NULL,
       "1.2.840.113549.1.9.1=#63657274696679407063612E64666E2E6465,"
       "CN=DFN Top Level Certification Authority,OU=DFN-PCA,"
       "O=Deutsches Forschungsnetz,C=DE" },
@@ -69,7 +73,6 @@ keys[] =
     { NULL }
   };
 
-
 int 
 main (int argc, char **argv)
 {
@@ -79,7 +82,8 @@ main (int argc, char **argv)
   gpgme_keylist_result_t result;
   int i = 0;
 
-  init_gpgme (GPGME_PROTOCOL_CMS);
+  err = gpgme_engine_check_version (GPGME_PROTOCOL_CMS);
+  fail_if_err (err);
 
   err = gpgme_new (&ctx);
   fail_if_err (err);
